from dash import html, dcc

def MainBox():

    return html.Div([
        html.Div([
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            dcc.Slider(
                min=0,
                max=100,
                step=1,
                value=50,
                marks={
                    0: {'label': '0'},
                    25: {'label': '25'},
                    50: {'label': '50'},
                    75: {'label': '75'},
                    100: {'label': '100'},
                },
                className="w-full"
            ),
            
            
        ],
        className="""
        w-1/4 h-full flex flex-col justify-evenly items-center

        """),
        # end of sliders

        # div holding 4 stacked scatter plots each with made up data
        html.Div([html.Div([
            dcc.Graph(
                figure={
                    'data': [
                        {'x': [1, 2, 3, 4, 5], 'y': [1, 2, 3, 4, 5], 'type': 'scatter', 'name': 'SF'},
                        {'x': [1, 2, 3, 4, 5], 'y': [5, 4, 3, 2, 1], 'type': 'scatter', 'name': u'Montréal'},
                    ],
                    'layout': {
                        'title': 'Dash Data Visualization',
                        'font': {
                            'size': 8
                        },
                         # legend underneath
                        'legend': {
                            'orientation': 'h',
                            'yanchor': 'bottom',
                            'y': 1.02,
                            'xanchor': 'right',
                            'x': .75,
                        }
                           
                    }
                },
                className="w-1/2 h-full"
            ),
            dcc.Graph(
                figure={
                    'data': [
                        {'x': [1, 2, 3, 4, 5], 'y': [1, 2, 3, 4, 5], 'type': 'scatter', 'name': 'SF'},
                        {'x': [1, 2, 3, 4, 5], 'y': [5, 4, 3, 2, 1], 'type': 'scatter', 'name': u'Montréal'},
                    ],
                    'layout': {
                        'title': 'Dash Data Visualization',
                        'font': {
                            'size': 8
                        },
                        # legend underneath
                        'legend': {
                            'orientation': 'h',
                            'yanchor': 'bottom',
                            'y': 1.02,
                            'xanchor': 'right',
                            'x': .75,
                        }
                    }
                },
                className="w-1/2 h-full"
            ),
            
            
            

        ], className="""w-3/4 h-1/2 flex"""),
        # end of scatter plots

        # div holding one tall bar chart with many horizontal bars
        html.Div([
            dcc.Graph(
    figure={
        'data': [
            {'x': [1, 2, 3, 4, 5], 'y': [1, 2, 3, 4, 5], 'type': 'bar', 'name': 'SF', 'orientation': 'v'},
            {'x': [1, 2, 3, 4, 5], 'y': [5, 4, 3, 2, 1], 'type': 'bar', 'name': 'Montréal', 'orientation': 'v'},
            {'x': [1, 2, 3, 4, 5], 'y': [2, 3, 3, 5, 4], 'type': 'bar', 'name': 'New York', 'orientation': 'v'},
        ],
        'layout': {
            'title': 'Dash Data Visualization',
            'font': {
                'size': 8,
                # make title size small
                'title': 4
            },
            'legend': {
                'orientation': 'h',
                'yanchor': 'bottom',
                'y': 1,
                'xanchor': 'center',
                'x': .5,
            },
        }
    }, className="w-full h-full"

)

        ], className="w-3/4 h-1/2 flex justify-evenly items-center"),]
        # end of bar chart div
        
        # wraps the charts only
        , className="w-3/4 h-full flex flex-col justify-evenly items-center")
        
        # wraps everything
        ], className="w-full h-3/4 shadow-lg rounded-xl bg-white flex")



import os

import redis
from rq import Worker, Queue, Connection

listen = ['high', 'default', 'low']

redis_url = os.getenv('REDIS_URL', 'redis://localhost:6379')

conn = redis.from_url(redis_url)

if __name__ == '__main__':
    with Connection(conn):
        worker = Worker(map(Queue, listen))
        worker.work()


# import os

# from redis import Redis
# from rq import Worker, Queue, Connection
# from typing import List

# DEFAULT_CONNECTION_URL = os.getenv('REDIS_URL', 'redis://localhost:6379')

# class TaskMaster:
#     def __init__(self, connection_url: str = DEFAULT_CONNECTION_URL, channel_subscriptions: List[str] = None):
#         """
#         Initialize the TaskMaster with the given connection URL.
#         """
#         self.connection = Redis.from_url(connection_url)
#         self.job_queue = Queue(connection=self.connection)
#         self.channel_subscriptions = channel_subscriptions or []

#     def work(self):
#         """
#         Start the worker and process tasks from the queue.
#         """
#         with Connection(self.connection):
#             print("Connected to Redis")
#             worker = Worker([self.job_queue])
#             print("Worker created")
#             worker.work()
#             print("Worker working")

# # Create a queue
# q = Queue(connection=Redis.from_url(DEFAULT_CONNECTION_URL))

# # Create a connection to the Redis server
# REDIS_CONNECTION_URL = os.getenv('REDIS_URL', 'redis://localhost:6379')
# worker_listen: List[str] = ["high", "default", "low"]

# # Create a worker
# worker = TaskMaster(REDIS_CONNECTION_URL,worker_listen)





from dash import Dash, html, dcc, callback, Output, Input
import plotly.express as px
import pandas as pd

df = pd.read_csv('https://raw.githubusercontent.com/plotly/datasets/master/gapminder_unfiltered.csv')

external_scripts = [
    {"src": "https://cdn.tailwindcss.com"}
]

external_stylesheets = [
    "https://rsms.me/inter/inter.css"
]

app = Dash(__name__, external_scripts=external_scripts, external_stylesheets=external_stylesheets)

app.layout = [
    html.H1(children='Title of Dash App', style={'textAlign':'center'}),
    dcc.Dropdown(df.country.unique(), 'Canada', id='dropdown-selection'),
    dcc.Graph(id='graph-content')
]

@callback(
    Output('graph-content', 'figure'),
    Input('dropdown-selection', 'value')
)
def update_graph(value):
    dff = df[df.country==value]
    return px.line(dff, x='year', y='pop')

def start() -> None:
    print("Super califragilisticxpealodoshis")
    app.run(debug=True)

if __name__ == '__main__':
    start()
